import { ref, computed } from 'vue';
import { defineStore } from 'pinia';

interface User {
    name: string;
    username: string;
    password: string;
    token: string;
    type: 'freelancer' | 'licensor';
}

const users: User[] = reactive([
    //suggest 3 users, 1 admin and 2 freelancers
    {
        name: 'Admin',
        username: 'admin@sedd.ae',
        password:   '123456',
        token: 'admin-token',
        type: 'licensor',
    },
    {
        name: 'Suhayeb',
        username: 'one@suhayeb.com',
        password: 'suhayeb',
        token: 'suhayeb-token',
        type: 'freelancer',
    },
    {
        name: 'Khalifa',
        username: 'khalifa@freelancer.io',
        password: 'khalifa',
        token: 'khalifa-token',
        type: 'freelancer',
    },    
])


export const useSessionStore = defineStore('session', () => {
    const user = ref<User | null>(null);

    const login = (username: string, pass:string) => {
        const foundUser = users.find(user => user.username === username && user.password === pass);
        if (foundUser) {
            user.value = foundUser;
        }
    };

    const signUp = (name: string, username: string, password: string, type: 'freelancer' | 'licensor') => {
        const newUser: User = {
            name,
            username,
            password,
            token: `${username}-token`,
            type,
        };
        users.push(newUser);
        user.value = newUser;
    };

    const logout = () => {
        user.value = null;
    };

    const isAuthenticated = computed(() => !!user.value);

    const isAdmin = computed(() => isAuthenticated && user.value?.type === 'licensor');

    const isFreelancer = computed(() => isAuthenticated && user.value?.type === 'freelancer');

    return {
        user,
        login,
        logout,
        signUp, // added signUp method to the return object
        isAuthenticated,
        isAdmin,
        isFreelancer,
    };
});